==> xwiki-commons-tool-test-component-7.3-rc-1-sources.jar: org/xwiki/test/annotation/BeforeComponent.java <==
/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.test.annotation;

import java.lang.annotation.Documented;
import java.lang.annotation.Inherited;
import java.lang.annotation.Retention;
import java.lang.annotation.Target;

import static java.lang.annotation.ElementType.METHOD;
import static java.lang.annotation.RetentionPolicy.RUNTIME;

/**
 * Calls methods annotated with this annotation before Component registration in
 * {@link org.xwiki.test.ComponentManagerRule}.
 *
 * @version $Id: cd60d207a715f63c0bf464cc5b9b3982873ef745 $
 * @since 4.3.1
 */
@Documented
@Retention(RUNTIME)
@Target({ METHOD })
@Inherited
public @interface BeforeComponent
{
}

==> xwiki-commons-tool-test-component-17.4.4-sources.jar: org/xwiki/test/annotation/BeforeComponent.java <==
/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.test.annotation;

import java.lang.annotation.Documented;
import java.lang.annotation.Inherited;
import java.lang.annotation.Retention;
import java.lang.annotation.Target;

import static java.lang.annotation.ElementType.METHOD;
import static java.lang.annotation.RetentionPolicy.RUNTIME;

/**
 * Calls methods annotated with this annotation before Component registration in
 * {@link org.xwiki.test.ComponentManagerRule}.
 *
 * @version $Id: b7c74c892c621f4b71de9682a6d9c105466c53ab $
 * @since 4.3.1
 */
@Documented
@Retention(RUNTIME)
@Target({ METHOD })
@Inherited
public @interface BeforeComponent
{
    /**
     * @return the test name to which this annotation applies to. When empty it applies to all tests.
     * @since 12.2
     */
    String value() default "";
}
